@@ -3,6 +3,7 @@ import pandas as pd
 import numpy as np
 import os
 import pkgutil
+from io import BytesIO
 
 class addone(object):
 
@@ -15,7 +16,7 @@ class addone(object):
         print('Random numpy integer: ' + str(np.random.randint(4)))
         data = pkgutil.get_data(__name__, 'data/sample_data.csv')
         print(data)
-        sample_df = pd.DataFrame(pd.read_csv('sample_data.csv'))
+        sample_df = pd.DataFrame(pd.read_csv(BytesIO(data)))
         print(sample_df.to_markdown())
 
 def main():
